@@ -1,4 +1,3 @@
-
 import os
 from sphinx.directives.other import TocTree
 import logging
@@ -15,19 +14,21 @@ logger = logging.getLogger(__name__)
 
 subproject_re = re.compile(r"""^\s?subproject:(.+)""")
 
+
 class SubprojectTocTree(TocTree):
     def parse_content(self, toctree: addnodes.toctree) -> List[Node]:
         master_readthedocs_url = get_normalized_master_url(self.config)
-        language = os.getenv('READTHEDOCS_LANGUAGE', default='en')
-        version = os.getenv('READTHEDOCS_VERSION', default='latest')
-        
+        language = os.getenv("READTHEDOCS_LANGUAGE", default="en")
+        version = os.getenv("READTHEDOCS_VERSION", default="latest")
+
         # First do some custom parsing ourselves, then for other options default to
         # default parser.
         to_add_later = {}
-        removal_index_shift = 0 # Needed because self.content.remove(entry) does not work
+        # Shift needed because self.content.remove(entry) does not work
+        removal_index_shift = 0
         content_old = deepcopy(self.content)
         mocked_found_docs = []
-        for i, entry in enumerate(self.content):
+        for i, entry in enumerate(content_old):
             if not entry:
                 continue
             # Parse entries in the form 'title <ref>'
@@ -37,19 +38,23 @@ class SubprojectTocTree(TocTree):
                 continue
             ref = explicit.group(2)
             title = explicit.group(1)
-            subproject = subproject_re.match(ref) # ref is 'subproject: ...'
+            subproject = subproject_re.match(ref)  # ref is 'subproject: ...'
             if not subproject:
                 mocked_found_docs.append(ref)
                 continue
-            if is_subproject(self.config) and toctree['parent'] != 'master__':
-                logger.error("Nested subprojects are not allowed. "
-                             "Either tag this project as the master by using 'is_subproject=False',"
-                             "or remove the subproject entry from the index.")
+            if is_subproject(self.config) and toctree["parent"] != "master__":
+                logger.error(
+                    "Nested subprojects are not allowed. "
+                    "Either tag this project as the master by using 'is_subproject=False',"
+                    "or remove the subproject entry from the index."
+                )
                 sys.exit(1)
             subproject_relative_path = subproject.group(1).strip()
             if subproject_relative_path:
-                ref = (f"{master_readthedocs_url}/projects/{subproject_relative_path}"
-                        f"/{language}/{version}/index.html")
+                ref = (
+                    f"{master_readthedocs_url}/projects/{subproject_relative_path}"
+                    f"/{language}/{version}/index.html"
+                )
                 to_add_later[i] = (title, ref)
                 # Remove from self.content, but not from the parents.
                 # So we do not use self.content.remove()
@@ -64,8 +69,8 @@ class SubprojectTocTree(TocTree):
         # which are hosted in the master project. So add them to 'found_docs'
         # Otherwise they would have been removed.
         orig_found_docs = self.env.found_docs.copy()
-        if is_subproject(self.config) and toctree.attributes['parent'] == "master__":
-            to_add = set(mocked_found_docs) 
+        if is_subproject(self.config) and toctree.attributes["parent"] == "master__":
+            to_add = set(mocked_found_docs)
             self.env.found_docs.update(to_add)
         ret = super().parse_content(toctree)
 
@@ -75,8 +80,8 @@ class SubprojectTocTree(TocTree):
 
         # Add our own custom parsed entries to the toctree entries
         for i, to_add in to_add_later.items():
-            toctree['entries'].insert(i, to_add)
+            toctree["entries"].insert(i, to_add)
 
         # Reset the content
         self.content = content_old
-        return ret
\ No newline at end of file
+        return ret
